@@ -1,7 +1,7 @@
 package Unicode::Normalize;
 
 BEGIN {
-    unless ("A" eq pack('U', 0x41) || "A" eq pack('U', ord("A"))) {
+    unless ("A" eq pack('U', 0x41)) {
 	die "Unicode::Normalize cannot stringify a Unicode code point\n";
     }
 }
@@ -12,7 +12,7 @@ use warnings;
 use Carp;
 use File::Spec;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 our $PACKAGE = __PACKAGE__;
 
 require Exporter;
@@ -189,27 +189,12 @@ foreach my $key (keys %Compat) {
 
 ######
 
-use constant UNICODE_FOR_PACK => ("A" eq pack('U', 0x41));
-use constant NATIVE_FOR_PACK  => ("A" eq pack('U', ord("A")));
-
-use constant UNICODE_FOR_UNPACK => (0x41 == unpack('U', "A"));
-use constant NATIVE_FOR_UNPACK  => (ord("A") == unpack('U', "A"));
-
 sub pack_U {
-    return UNICODE_FOR_PACK
-	? pack('U*', @_)
-	: NATIVE_FOR_PACK
-	    ? pack('U*', map utf8::unicode_to_native($_), @_)
-	    : die "$PACKAGE, a Unicode code point cannot be stringified.\n";
+    return pack('U*', @_);
 }
 
 sub unpack_U {
-    return UNICODE_FOR_UNPACK
-	? unpack('U*', shift)
-	: NATIVE_FOR_UNPACK
-	    ? map(utf8::native_to_unicode($_), unpack 'U*', shift)
-	    : die "$PACKAGE, a code point returned from unpack U " .
-		"cannot be converted into Unicode.\n";
+    return unpack('U*', pack('U*').shift);
 }
 
 ######
@@ -238,7 +223,7 @@ sub decomposeHangul {
        VBase + $VIndex,
       $TIndex ? (TBase + $TIndex) : (),
     );
-    wantarray ? @ret : pack('U*', @ret);
+    wantarray ? @ret : pack_U(@ret);
 }
 
 ##########
